aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/pdf/SkPDFPage.h
diff options
context:
space:
mode:
authorGravatar edisonn@google.com <edisonn@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-02-27 19:45:11 +0000
committerGravatar edisonn@google.com <edisonn@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-02-27 19:45:11 +0000
commit194b7cdb5024719aeb7e2878f69b8f4b144aa9c4 (patch)
tree69643441bfd4e03cff4f055b63c6060b878420f9 /src/pdf/SkPDFPage.h
parent54f0d1b7113cb0dc184e522539aab1030a28a421 (diff)
resubmit after fixing assert issue: https://codereview.appspot.com/6744050
git-svn-id: http://skia.googlecode.com/svn/trunk@7892 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'src/pdf/SkPDFPage.h')
-rw-r--r--src/pdf/SkPDFPage.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/pdf/SkPDFPage.h b/src/pdf/SkPDFPage.h
index 72ba335e66..17fd437623 100644
--- a/src/pdf/SkPDFPage.h
+++ b/src/pdf/SkPDFPage.h
@@ -40,13 +40,15 @@ public:
* that the page is part of.
* @param catalog The catalog to add page content objects to.
* @param firstPage Indicate if this is the first page of a document.
* @param resourceObjects All the resource objects (recursively) used on
* the page are added to this array. This gives
* the caller a chance to deduplicate resources
* across pages.
+ * @param knownResourceObjects The set of resources to be ignored.
*/
void finalizePage(SkPDFCatalog* catalog, bool firstPage,
- SkTDArray<SkPDFObject*>* resourceObjects);
+ const SkTSet<SkPDFObject*>& knownResourceObjects,
+ SkTSet<SkPDFObject*>* newResourceObjects);
/** Determine the size of the page content and store to the catalog
* the offsets of all nonresource-indirect objects that make up the page
@@ -40,13 +40,15 @@ public:
* @param catalog The catalog to add page content objects to.
* @param firstPage Indicate if this is the first page of a document.
- * @param resourceObjects All the resource objects (recursively) used on
+ * @param newResourceObjects All the resource objects (recursively) used on
* the page are added to this array. This gives
* the caller a chance to deduplicate resources